pub struct HideSet(/* private fields */);Expand description
An interned set of macro names.
Only meaningful together with the HideSets table it was created by. There is one
table per translation unit, so mixing two of them is a bug rather than a case to handle.
Implementations