pub struct LineDirective {
pub span: Span,
pub line: u32,
pub file: Option<Symbol>,
}Expand description
A #line directive, kept for the source map to apply.
Fields
span: SpanWhere the directive is.
line: u32The line number the next line is to be called.
file: Option<Symbol>The file name the following lines are to be called, if one was given.